Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(86)

Unified Diff: src/codec/SkGifCodec.h

Issue 2445653004: Rename GIFImageReader to SkGifImageReader (Closed)
Patch Set: Remove dependent patch set Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/codec/SkGifCodec.h
diff --git a/src/codec/SkGifCodec.h b/src/codec/SkGifCodec.h
index 544ba1369524a82ed0599d55b96422ecd7753ae0..b5f8f7ce0c48958685f96d8592e3e94be22892bc 100644
--- a/src/codec/SkGifCodec.h
+++ b/src/codec/SkGifCodec.h
@@ -12,7 +12,7 @@
#include "SkImageInfo.h"
#include "SkSwizzler.h"
-#include "GIFImageReader.h"
+#include "SkGifImageReader.h"
/*
*
@@ -30,7 +30,7 @@ public:
*/
static SkCodec* NewFromStream(SkStream*);
// Callback for GIFImageReader when a row is available.
bool haveDecodedRow(size_t frameIndex, const unsigned char* rowBegin,
size_t rowNumber, unsigned repeatCount, bool writeTransparentPixels);
protected:
@@ -127,31 +127,31 @@ private:
/*
* Creates an instance of the decoder
* Called only by NewFromStream
* Takes ownership of the GIFImageReader
*/
- SkGifCodec(const SkEncodedInfo&, const SkImageInfo&, GIFImageReader*);
+ SkGifCodec(const SkEncodedInfo&, const SkImageInfo&, SkGifImageReader*);
- std::unique_ptr<GIFImageReader> fReader;
- std::unique_ptr<uint8_t[]> fTmpBuffer;
- std::unique_ptr<SkSwizzler> fSwizzler;
- sk_sp<SkColorTable> fCurrColorTable;
+ std::unique_ptr<SkGifImageReader> fReader;
+ std::unique_ptr<uint8_t[]> fTmpBuffer;
+ std::unique_ptr<SkSwizzler> fSwizzler;
+ sk_sp<SkColorTable> fCurrColorTable;
// We may create a dummy table if there is not a Map in the input data. In
// that case, we set this value to false, and we can skip a lot of decoding
// work (which would not be meaningful anyway). We create a "fake"/"dummy"
// one in that case, so the client and the swizzler have something to draw.
- bool fCurrColorTableIsReal;
+ bool fCurrColorTableIsReal;
// Whether the background was filled.
- bool fFilledBackground;
+ bool fFilledBackground;
// True on the first call to onIncrementalDecode. This value is passed to
// decodeFrame.
- bool fFirstCallToIncrementalDecode;
+ bool fFirstCallToIncrementalDecode;
- void* fDst;
- size_t fDstRowBytes;
+ void* fDst;
+ size_t fDstRowBytes;
// Updated inside haveDecodedRow when rows are decoded, unless we filled
// the background, in which case it is set once and left alone.
- int fRowsDecoded;
+ int fRowsDecoded;
typedef SkCodec INHERITED;
};
« no previous file with comments | « gyp/codec.gyp ('k') | src/codec/SkGifCodec.cpp » ('j') | third_party/gif/SkGifImageReader.h » ('J')
@@ -30,7 +30,7 @@ public:
*/
static SkCodec* NewFromStream(SkStream*);
- // Callback for GIFImageReader when a row is available.
+ // Callback for SkGifImageReader when a row is available.
bool haveDecodedRow(size_t frameIndex, const unsigned char* rowBegin,
size_t rowNumber, unsigned repeatCount, bool writeTransparentPixels);
@@ -127,31 +127,31 @@ private:
* Creates an instance of the decoder
* Called only by NewFromStream
- * Takes ownership of the GIFImageReader
+ * Takes ownership of the SkGifImageReader
*/

Powered by Google App Engine
This is Rietveld 408576698